unit dmtest_pluginImpl;

interface

uses DMPluginIntf, Classes, Dialogs;
const
  //specify here your plug-in info
  myPluginID = '{45145BBE-DCAE-4187-B981-FE9410F6DA5D}';//you MUST specify here a unique ID for your plug-in (use Ctrl+Shift+G in Delphi to automatically generate it)
  myPluginName = 'Test Plug-in';//Plug-in name in English 
  myPluginVersion = '0.1.1.1';
  myPluginEmail = 'info@westbyte.com';
  myPluginHomePage = 'http://www.westbyte.com/ida/';
  myPluginCopyRight = chr(169)+'2006 WestByte';
  myMinNeedAppVersion = '5.0.2';//version without build
  //plug-in description. Can be both in English and Russian. Also may contain instructions on plug-in usage.
  myPluginDescription = 'Test Plug-in for show how create plugins for IDA';
  myPluginDescriptionRussian = '        DM.      .   Delphi 7.';
  
type
TDMTestPlugIn = class(TInterfacedObject, IDMPlugIn)
  private
    myIDmInterface: IDmInterface;
  protected

  public
    function getID: WideString; stdcall;
    //-----info
    function GetName: WideString; stdcall;//get plug-in info
    function GetVersion: WideString; stdcall;//get plug-in info
    function GetDescription(language: WideString): WideString; stdcall;//get plug-in info
    function GetEmail: WideString; stdcall;//get plug-in info
    function GetHomepage: WideString; stdcall;//get plug-in info
    function GetCopyright: WideString; stdcall;//get plug-in info
    function GetMinAppVersion: WideString; stdcall;//get minimum version of IDA with which a plug-in can work

    //------
    procedure PluginInit(_IDmInterface: IDmInterface); stdcall;//initialize plug-in and pass interface to access IDA
    procedure PluginConfigure(params: WideString); stdcall;//show plug-in configuration window (you yourself have to implement this window)
    procedure BeforeUnload; stdcall;//called before plug-in is deleted

    function EventRaised(eventType: WideString; eventData: WideString): WideString; stdcall;//called from IDA when an event occurs
    { plug-in ID }
    property ID: WideString read getID;

  published

end;

implementation
//------------------------------------------------------------------------------
function TDMTestPlugIn.GetName: WideString;//get plug-in info
begin
  Result := myPluginName;
end;
//------------------------------------------------------------------------------
function TDMTestPlugIn.GetVersion: WideString;//get plug-in info
begin
  Result := myPluginVersion;
end;
//------------------------------------------------------------------------------
function TDMTestPlugIn.GetDescription(language: WideString): WideString;//get plug-in info
begin
  if (language = 'russian') or (language = 'ukrainian') or (language = 'belarusian') then
    Result := myPluginDescriptionRussian
  else
    Result := myPluginDescription;
end;
//------------------------------------------------------------------------------
function TDMTestPlugIn.getID: WideString; stdcall;
begin
  Result:= myPluginID;
end;
//------------------------------------------------------------------------------
procedure TDMTestPlugIn.PluginInit(_IDmInterface: IDmInterface);//initialize plug-in and pass interface to access IDA
begin
  myIDmInterface := _IDmInterface;
end;
//------------------------------------------------------------------------------
procedure TDMTestPlugIn.BeforeUnload;
begin
  myIDmInterface := nil;
//  ShowMessage('Unload plug-in '+myPluginName);
end;
//------------------------------------------------------------------------------
procedure TDMTestPlugIn.PluginConfigure(params: WideString);//show plug-in configuration window
begin
  ShowMessage('Showing config form');
  myIDmInterface.DoAction('AddingURL', '<url>http://www.westbyte.com/plugin</url> <sectionslimit>2</sectionslimit>');
//  ShowMessage(myIDmInterface.DoAction('GetDownloadIDsList', '3'));
end;
//------------------------------------------------------------------------------
function TDMTestPlugIn.EventRaised(eventType: WideString; eventData: WideString): WideString;//called from IDA when an event occurs
begin
  if eventType = 'dm_download_added' then
    ShowMessage('Added ID='+eventData);
//  ShowMessage('Event RAISE'+#13#10+'eventType='+eventType+#13#10+'eventData='+eventData);
end;
//------------------------------------------------------------------------------
function TDMTestPlugIn.GetEmail: WideString;//get plug-in info
begin
  Result:= myPluginEmail;
end;
//------------------------------------------------------------------------------
function TDMTestPlugIn.GetHomepage: WideString;//get plug-in info
begin
  Result:= myPluginHomePage;
end;
//------------------------------------------------------------------------------
function TDMTestPlugIn.GetCopyright: WideString;//get plug-in info
begin
  Result:= myPluginCopyright;
end;
//------------------------------------------------------------------------------
function TDMTestPlugIn.GetMinAppVersion: WideString;//get minimum version of IDA with which a plug-in can work
begin
  Result:= myMinNeedAppVersion;
end;
//------------------------------------------------------------------------------

end.
